@@ -4,20 +4,20 @@ import (
 	"bytes"
 	"testing"
 
-	"github.com/apex/log"
-	"github.com/apex/log/handlers/cli"
-	"github.com/fatih/color"
+	"github.com/caarlos0/log"
+	"github.com/charmbracelet/lipgloss"
 	"github.com/goreleaser/goreleaser/internal/golden"
 	"github.com/goreleaser/goreleaser/pkg/config"
 	"github.com/goreleaser/goreleaser/pkg/context"
+	"github.com/muesli/termenv"
 	"github.com/stretchr/testify/require"
 )
 
 func TestNotice(t *testing.T) {
-	var w bytes.Buffer
+	lipgloss.SetColorProfile(termenv.Ascii)
 
-	color.NoColor = true
-	log.SetHandler(cli.New(&w))
+	var w bytes.Buffer
+	log.Log = log.New(&w)
 
 	log.Info("first")
 	ctx := context.New(config.Project{})
@@ -29,10 +29,10 @@ func TestNotice(t *testing.T) {
 }
 
 func TestNoticeCustom(t *testing.T) {
-	var w bytes.Buffer
+	lipgloss.SetColorProfile(termenv.Ascii)
 
-	color.NoColor = true
-	log.SetHandler(cli.New(&w))
+	var w bytes.Buffer
+	log.Log = log.New(&w)
 
 	log.Info("first")
 	ctx := context.New(config.Project{})
